.. Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
.. For details: https://github.com/coveragepy/coveragepy/blob/main/NOTICE.txt

.. _api_exceptions:

Coverage exceptions
-------------------

.. automodule:: coverage.exceptions
    :members:
    :member-order: bysource
